@@ -104,14 +104,15 @@ class CustomTitlebarWindow(FramelessWindow):
                 self.close()
             if e.type() == 105:
                 self.__toggleFullScreenFromInnerWidget(e)
-
+            # catch the title change event
+            if e.type() == 33:
+                title = obj.windowTitle()
+                self.__titleLbl.setText(title)
+                self.setWindowTitle(title)
         # catch the enter event
         if e.type() == 10:
             self.unsetCursor()
             self._resizing = False
-        # catch the title change event
-        if e.type() == 33:
-            self.__titleLbl.setText(obj.windowTitle())
         if obj.objectName() == 'navWidget':
             # catch the menubar double click or mouse move event
             if isinstance(obj, QMenuBar):
@@ -250,9 +251,7 @@ class CustomTitlebarWindow(FramelessWindow):
         icon_filename = self.__getWindowIcon(icon_filename)
         self.setWindowIcon(QIcon(icon_filename))
 
-    def setMenuTitle(self, title: str = '', icon_filename: str = '', font: QFont = QFont('Arial', 9)):
-        # set menu title
-        title = self.__getWindowTitle(title)
+    def __setMenuTitle(self, title, font):
         self.__titleLbl.setText(title)
         self.__titleLbl.setFont(font)
         self.__titleLbl.setMinimumHeight(self.__menubar.height())
@@ -263,19 +262,32 @@ class CustomTitlebarWindow(FramelessWindow):
                 lay.insertWidget(0, self.__titleLbl)
         else:
             self.__menubar.setCornerWidget(self.__titleLbl, Qt.TopRightCorner)
-        self.setWindowTitle(title)
 
-        # set menu icon
+    def __setMenuIcon(self, icon_filename):
         self.__iconLbl = SvgLabel()
         self.__iconLbl.setSvgFile(icon_filename)
         w = h = self.__titleLbl.font().pointSize()*2*QApplication.screens()[0].logicalDotsPerInch()/96.0
         self.__iconLbl.setFixedSize(w, h)
-        self.__menubar.setCornerWidget(self.__iconLbl, Qt.TopLeftCorner)
+        lay = QHBoxLayout()
+        lay.addWidget(self.__iconLbl)
+        lay.setContentsMargins(5, 0, 0, 0)
+        leftCornerWidget = QWidget()
+        leftCornerWidget.setLayout(lay)
+        self.__menubar.setCornerWidget(leftCornerWidget, Qt.TopLeftCorner)
+
+    def setMenuAsTitleBar(self, title: str = '', icon_filename: str = '', font: QFont = QFont('Arial', 9)):
+        title = self.__getWindowTitle(title)
+        self.setWindowTitle(title)
         self.__setWindowIcon(icon_filename)
+        # set menu title
+        self.__setMenuTitle(title, font)
+        # set menu icon
+        self.__setMenuIcon(icon_filename)
 
     def setTopTitleBar(self, title: str = '', icon_filename: str = '', font: QFont = QFont('Arial', 14),
                        align=Qt.AlignCenter, bottom_separator: bool = False):
         title = self.__getWindowTitle(title)
+        self.setWindowTitle(title)
         self.__setWindowIcon(icon_filename)
 
         if isinstance(self.__menubar, QMenuBar):
@@ -297,9 +309,6 @@ class CustomTitlebarWindow(FramelessWindow):
 
         self.setPressToMove(False)
 
-        # Set app title
-        self.setWindowTitle(title)
-
     def getCornerWidget(self):
         return self.__menubar.cornerWidget()
 
